@@ -16,7 +16,6 @@
 
 import collections
 import functools
-import warnings
 
 import grpc
 
@@ -26,20 +25,6 @@ import google.auth.credentials
 import google.auth.transport.grpc
 import google.auth.transport.requests
 
-try:
-    import grpc_gcp
-
-    warnings.warn(
-        """Support for grpcio-gcp is deprecated. This feature will be
-        removed from `google-api-core` after January 1, 2024. If you need to
-        continue to use this feature, please pin to a specific version of
-        `google-api-core`.""",
-        DeprecationWarning,
-    )
-    HAS_GRPC_GCP = True
-except ImportError:
-    HAS_GRPC_GCP = False
-
 
 # The list of gRPC Callable interfaces that return iterators.
 _STREAM_WRAP_CLASSES = (grpc.UnaryStreamMultiCallable, grpc.StreamStreamMultiCallable)
@@ -290,9 +275,7 @@ def create_channel(
         default_scopes (Sequence[str]): Default scopes passed by a Google client
             library. Use 'scopes' for user-defined scopes.
         default_host (str): The default endpoint. e.g., "pubsub.googleapis.com".
-        kwargs: Additional key-word args passed to
-            :func:`grpc_gcp.secure_channel` or :func:`grpc.secure_channel`.
-            Note: `grpc_gcp` is only supported in environments with protobuf < 4.0.0.
+        kwargs: Additional key-word args passed to :func:`grpc.secure_channel`.
 
     Returns:
         grpc.Channel: The created channel.
@@ -311,8 +294,6 @@ def create_channel(
         default_host=default_host,
     )
 
-    if HAS_GRPC_GCP:  # pragma: NO COVER
-        return grpc_gcp.secure_channel(target, composite_credentials, **kwargs)
     return grpc.secure_channel(target, composite_credentials, **kwargs)
 
 
